@@ -3,7 +3,6 @@
 # flake8: noqa
 from __future__ import absolute_import
 # import models into model package
-from opera.api.openapi.models.csar_validation_input import CsarValidationInput
 from opera.api.openapi.models.deployment_input import DeploymentInput
 from opera.api.openapi.models.diff import Diff
 from opera.api.openapi.models.diff_request import DiffRequest
@@ -17,4 +16,5 @@ from opera.api.openapi.models.packaging_input import PackagingInput
 from opera.api.openapi.models.packaging_result import PackagingResult
 from opera.api.openapi.models.unpackaging_input import UnpackagingInput
 from opera.api.openapi.models.update_request import UpdateRequest
+from opera.api.openapi.models.validation_input import ValidationInput
 from opera.api.openapi.models.validation_result import ValidationResult
